Canonicalization version 1 hashes normalized R objects with SHA-256 over a package-owned tagged binary encoding. It is stable for supported package operations and round trips, but is deliberately R-only rather than a cross-language wire encoding.
Canonicalization version 1 hashes normalized R objects with SHA-256 over a package-owned tagged binary encoding. It is stable for supported package operations and round trips, but is deliberately R-only rather than a cross-language wire encoding.