Get Parcellation Information from a BIDS H5 Dataset
Source:R/all_generic.R, R/bids_h5_dataset.R
parcellation_info.RdGeneric function to retrieve parcellation metadata from a BIDS HDF5 dataset stored in parcellated mode.
R/all_generic.R, R/bids_h5_dataset.R
parcellation_info.RdGeneric function to retrieve parcellation metadata from a BIDS HDF5 dataset stored in parcellated mode.